aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/appservice_room_directory.h
diff options
context:
space:
mode:
authorAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
committerAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
commit09eb39236666e81d5da014acea011dcd74d0999b (patch)
tree52876d96be71be1a39d5d935c1295a51995e8949 /lib/csapi/appservice_room_directory.h
parentf1788ee27f33e9339334e0d79bde9a27d9ce2e44 (diff)
parenta4e78956f105875625b572d8b98459ffa86fafe5 (diff)
downloadlibquotient-09eb39236666e81d5da014acea011dcd74d0999b.tar.gz
libquotient-09eb39236666e81d5da014acea011dcd74d0999b.zip
Update upstream source from tag 'upstream/0.6.4'
Update to upstream version '0.6.4' with Debian dir aa8705fd74743e79c043bc9e3e425d5064404cfe
Diffstat (limited to 'lib/csapi/appservice_room_directory.h')
-rw-r--r--lib/csapi/appservice_room_directory.h67
1 files changed, 36 insertions, 31 deletions
diff --git a/lib/csapi/appservice_room_directory.h b/lib/csapi/appservice_room_directory.h
index f35198b3..3fa02a07 100644
--- a/lib/csapi/appservice_room_directory.h
+++ b/lib/csapi/appservice_room_directory.h
@@ -6,36 +6,41 @@
#include "jobs/basejob.h"
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Updates a room's visibility in the application service's room
+ * directory.
+ *
+ * Updates the visibility of a given room on the application service's room
+ * directory.
+ *
+ * This API is similar to the room directory visibility API used by clients
+ * to update the homeserver's more general room directory.
+ *
+ * This API requires the use of an application service access token
+ * (``as_token``) instead of a typical client's access_token. This API cannot be
+ * invoked by users who are not identified as application services.
+ */
+class UpdateAppserviceRoomDirectoryVsibilityJob : public BaseJob {
+public:
+ /*! \brief Updates a room's visibility in the application service's room
+ * directory.
+ *
+ * \param networkId
+ * The protocol (network) ID to update the room list for. This would
+ * have been provided by the application service as being listed as
+ * a supported protocol.
+ *
+ * \param roomId
+ * The room ID to add to the directory.
+ *
+ * \param visibility
+ * Whether the room should be visible (public) in the directory
+ * or not (private).
+ */
+ explicit UpdateAppserviceRoomDirectoryVsibilityJob(const QString& networkId,
+ const QString& roomId,
+ const QString& visibility);
+};
- /// Updates a room's visibility in the application service's room directory.
- ///
- /// Updates the visibility of a given room on the application service's room
- /// directory.
- ///
- /// This API is similar to the room directory visibility API used by clients
- /// to update the homeserver's more general room directory.
- ///
- /// This API requires the use of an application service access token (``as_token``)
- /// instead of a typical client's access_token. This API cannot be invoked by
- /// users who are not identified as application services.
- class UpdateAppserviceRoomDirectoryVsibilityJob : public BaseJob
- {
- public:
- /*! Updates a room's visibility in the application service's room directory.
- * \param networkId
- * The protocol (network) ID to update the room list for. This would
- * have been provided by the application service as being listed as
- * a supported protocol.
- * \param roomId
- * The room ID to add to the directory.
- * \param visibility
- * Whether the room should be visible (public) in the directory
- * or not (private).
- */
- explicit UpdateAppserviceRoomDirectoryVsibilityJob(const QString& networkId, const QString& roomId, const QString& visibility);
- };
-} // namespace QMatrixClient
+} // namespace Quotient